import React from "react"
import { Provider as ProviderX } from 'react-redux'
import { RootStore, AppPersistor } from "./config";
import { PersistGate } from 'redux-persist/integration/react'
import { xSetState, getStateForKey } from "./methods";

const stateInitalizer = (initialState: object) => {
    if (typeof initialState != 'object') { throw Error('initialState is Required') }
    const didInit = getStateForKey('didInit')
    if (!didInit) { xSetState({ ...initialState, didInit: true }) }
}

/** 
 * Step Provider
 * @param {object} initialState Required
 * @example
 * <Provider
 *  initialState={{ user: { data: {}, loggedIn: false}}}
 *  loading={<ActivityIndicator />}>
 *   <Navigation />
 * </Provider>
*/
export const Provider = ({ initialState = {}, loading, children, }) => {
    stateInitalizer(initialState)
    return (
        <ProviderX store={RootStore}>
            <PersistGate
                persistor={AppPersistor}
                loading={loading}
                children={children}
            />
        </ProviderX>
    );
}